@@ -7,3 +7,7 @@ from . import aggregation
 from . import fabba_agg_memview
 from . import fabba_agg
 from . import load_datasets
+from . import symbolic_representation
+from .symbolic_representation import *
+from .chainApproximation import *
+from .digitization import *
